"use client"
import React, { useState } from 'react';
import { motion, AnimatePresence } from 'framer-motion';
import { ChevronDown } from 'lucide-react';
import { useRouter } from 'next/navigation'; // Import Next.js router

const AnimatedText = ({ isLogin, onClick }) => {
  const [isDropdownOpen, setIsDropdownOpen] = useState(false);
  const router = useRouter(); // Initialize Next.js router

  // Retrieve user data from localStorage
  const userData = JSON.parse(localStorage.getItem('userData'));
  const userName = userData ? userData.name : '';
  const userId = userData ? userData.user_id : null;

  // Logout handler
  const handleLogout = () => {
    // Clear all localStorage items related to user
    localStorage.removeItem('userData');
    localStorage.removeItem('token'); // Clear authentication token if exists
    localStorage.clear(); // Use with caution, only if no other app data is stored

    // Redirect to home page using Next.js router
    router.push('/');
  };

  // Dashboard navigation handler
  const handleDashboardNavigation = () => {
    // Navigate to dashboard with user_id using Next.js router
    if (userId) {
      router.push(`/dashboard/${userId}`);
    } else {
      // Fallback in case user_id is not available
      router.push('/dashboard');
    }
  };

  // Rest of the component remains the same as in the previous example
  if (userName) {
    return (
      <div className="relative z-50">
        <div
          className="relative h-6 w-auto min-w-[5rem] overflow-hidden cursor-pointer"
          onClick={() => setIsDropdownOpen(!isDropdownOpen)}
        >
          <motion.div
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            className="flex items-center font-semibold text-blue-600 justify-center"
          >
            <span className="mr-1 truncate max-w-[10rem]">{userName}</span>
            <ChevronDown size={16} className="flex-shrink-0" />
          </motion.div>
        </div>
        {isDropdownOpen && (
          <motion.div
            initial={{ opacity: 0, y: -10 }}
            animate={{ opacity: 1, y: 0 }}
            exit={{ opacity: 0, y: -10 }}
            className="absolute top-full right-0 mt-2 w-48 bg-white shadow-lg rounded-md border border-gray-200 z-50"
          >
            <div className="py-1">
              <button
                onClick={handleDashboardNavigation}
                className="block w-full text-left px-4 py-2 text-sm text-gray-700 hover:bg-gray-100 focus:outline-none focus:bg-gray-100"
              >
                Dashboard
              </button>
              <button
                onClick={handleLogout}
                className="block w-full text-left px-4 py-2 text-sm text-red-600 hover:bg-gray-100 focus:outline-none focus:bg-gray-100"
              >
                Logout
              </button>
            </div>
          </motion.div>
        )}
      </div>
    );
  }

  // Existing return for login/register view
  return (
    <div className="relative h-6 w-20 overflow-hidden">
      <AnimatePresence mode="wait">
        <motion.p
          key={isLogin ? 'login' : 'register'}
          initial={{ y: 30 }}
          animate={{ y: 0 }}
          exit={{ y: -30 }}
          transition={{ duration: 0.3, ease: 'easeInOut' }}
          className={`font-semibold absolute w-full text-center cursor-pointer ${
            isLogin ? 'text-base' : 'text-sm'
          }`}
          onClick={onClick}
        >
          {isLogin ? 'LOGIN' : 'REGISTER'}
        </motion.p>
      </AnimatePresence>
    </div>
  );
};

export default AnimatedText;